const axios         = require('axios')
const session       = require('./session')
const { getSigner } = require('./ethers')

const deposit = async (amount, poolId, unit) => {
  const endpoint = process.env.ENDPOINT
  const token    = await session.getValidToken()
  const data     = { deposit: { amount, unit, pool_id: poolId } }
  const config   = { headers: session.getAuthHeader(token) }
  const response = await axios.post(`${endpoint}/v1/deposits`, data, config)

  if (response.status === 200) {
    for (let data of response.data.data) {
      const { chain_id: chainId, rpc_url: rpcUrl } = data.provider
      const signer = getSigner({ chainId, rpcUrl })

      console.log('Making operations using RPC', rpcUrl)

      for (let transactionData of data.transactions) {
        const { description, transaction } = transactionData

        console.log(`Unsigned ${description} transaction`, transaction)
        console.log(`Sending ${description}...`)

        const transactionResponse = await signer.sendTransaction(transaction)

        console.log(`${description} transaction hash`, transactionResponse.hash)

        const transactionReceipt = await transactionResponse.wait()

        // Status === 1 means success, 0 means it was rejected
        if (transactionReceipt.status) {
          console.log(`${description} transaction completed`, transactionReceipt.transactionHash)
        } else {
          console.log(`${description} transaction failed`, transactionReceipt.transactionHash)
        }
      }
    }
  } else {
    console.error(`${description} response status was ${response.status} (and 200 was expected)`)
  }
}

module.exports = deposit
